@@ -7,6 +7,7 @@ from multiprocessing import Process, cpu_count, Queue
 from collections import namedtuple
 from operator import attrgetter
 from tqdm import tqdm
+from tensorflow.keras.utils import HDF5Matrix
 import time
 
 
@@ -29,6 +30,9 @@ def build_annoy_index(X, path, ntrees=50, build_index_on_disk=True, verbose=1):
 
     """
 
+    if not isinstance(X, HDF5Matrix):
+        X = X.reshape((X.shape[0], -1))
+
     index = AnnoyIndex(X.shape[1], metric='angular')
     if build_index_on_disk:
         index.on_disk_build(path)
@@ -58,6 +62,9 @@ def extract_knn(X, index_filepath, k=150, search_k=-1, verbose=1):
     """ Starts multiple processes to retrieve nearest neighbours using
         an Annoy Index in parallel """
 
+    if not isinstance(X, HDF5Matrix):
+        X = X.reshape((X.shape[0], -1))
+
     n_dims = X.shape[1]
 
     chunk_size = X.shape[0] // cpu_count()
